mangadap.survey package
=======================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.survey.dapall
   mangadap.survey.drpcomplete
   mangadap.survey.manga_dap
   mangadap.survey.rundap

Module contents
---------------

.. automodule:: mangadap.survey
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
